@@ -44,14 +44,15 @@ class Exam(object):
             for attr, class_value in vars(base).iteritems():
                 resolved_value = getattr(type(self), attr, False)
 
+                if type(resolved_value) is not kind:
+                    continue
                 # If the attribute inside of this base is not the exact same
                 # value as the one in type(self), that means that it's been
                 # overwritten somewhere down the line and we shall skip it
-                if class_value is not resolved_value:
-                    continue
-                elif type(resolved_value) is not kind:
+                elif class_value is not resolved_value:
                     continue
                 else:
+                    print 'yielding', attr, 'from', base
                     yield attr, resolved_value
 
     def setUp(self):
