@@ -107,9 +107,10 @@ class mock_import(patch.dict):
         @functools.wraps(func)
         def inner(*args, **kwargs):
             args = list(args)
-            args.append(self.modules[self.path])
+            args.insert(1, self.modules[self.path])
 
             with self:
+                print func, args, kwargs
                 func(*args, **kwargs)
 
         return inner
